"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = MultiWordHighlighter;
var _react = _interopRequireDefault(require("react"));
var _highlightWordsCore = require("highlight-words-core");
var _reactNative = require("react-native");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function MultiWordHighlighter(props) {
  const {
    autoEscape = false,
    searchWords,
    textToHighlight,
    caseSensitive = false,
    viewContainerStyle = {},
    defaultHighlightTextStyle = {},
    replaceAllMatchedTextWith
  } = props;
  const searchWordsArray = searchWords.map(searchWord => searchWord.word);
  const wordToConfigMap = {};
  searchWords.forEach(searchWord => {
    wordToConfigMap[searchWord.word] = searchWord;
  });
  const chunks = (0, _highlightWordsCore.findAll)({
    autoEscape,
    searchWords: searchWordsArray,
    textToHighlight,
    caseSensitive
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.containerStyle, viewContainerStyle]
  }, chunks.map((chunk, idx) => {
    const {
      end,
      highlight,
      start
    } = chunk;
    const text = textToHighlight.substr(start, end - start);
    if (highlight) {
      var _wordToConfigMap$text, _wordToConfigMap$text2, _wordToConfigMap$text3, _wordToConfigMap$text4;
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: idx,
        style: [(_wordToConfigMap$text = wordToConfigMap[text]) !== null && _wordToConfigMap$text !== void 0 && _wordToConfigMap$text.textStyle ? (_wordToConfigMap$text2 = wordToConfigMap[text]) === null || _wordToConfigMap$text2 === void 0 ? void 0 : _wordToConfigMap$text2.textStyle : defaultHighlightTextStyle]
      }, (_wordToConfigMap$text3 = wordToConfigMap[text]) !== null && _wordToConfigMap$text3 !== void 0 && _wordToConfigMap$text3.replace ? (_wordToConfigMap$text4 = wordToConfigMap[text]) === null || _wordToConfigMap$text4 === void 0 ? void 0 : _wordToConfigMap$text4.replace : replaceAllMatchedTextWith ? replaceAllMatchedTextWith : text);
    } else {
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: idx
      }, text);
    }
  }));
}
const styles = _reactNative.StyleSheet.create({
  containerStyle: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
//# sourceMappingURL=MultiWordHighlighter.js.map